==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/outputs/AnalyticsApplicationInputsSchemaRecordFormatMappingParameters.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property csv Mapping information when the record format uses delimiters.
 * See CSV Mapping Parameters below for more details.
 * @property json Mapping information when JSON is the record format on the streaming source.
 * See JSON Mapping Parameters below for more details.
 */
public data class AnalyticsApplicationInputsSchemaRecordFormatMappingParameters(
    public val csv: AnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv? = null,
    public val json: AnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.kinesis.outputs.AnalyticsApplicationInputsSchemaRecordFormatMappingParameters):
            AnalyticsApplicationInputsSchemaRecordFormatMappingParameters =
            AnalyticsApplicationInputsSchemaRecordFormatMappingParameters(
                csv = javaType.csv().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                json = javaType.json().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/outputs/AnalyticsApplicationInputsSchemaRecordFormatMappingParameters.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property csv Mapping information when the record format uses delimiters.
 * See CSV Mapping Parameters below for more details.
 * @property json Mapping information when JSON is the record format on the streaming source.
 * See JSON Mapping Parameters below for more details.
 */
public data class AnalyticsApplicationInputsSchemaRecordFormatMappingParameters(
    public val csv: AnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv? = null,
    public val json: AnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.kinesis.outputs.AnalyticsApplicationInputsSchemaRecordFormatMappingParameters): AnalyticsApplicationInputsSchemaRecordFormatMappingParameters =
            AnalyticsApplicationInputsSchemaRecordFormatMappingParameters(
                csv = javaType.csv().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                json = javaType.json().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
